==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-tr_TR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Turkish (Turkey) (http://www.transifex.com/tine20/tine20/language/tr_TR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: tr_TR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Hat"

, "Caller Id"
: "Numaram"

, "Start"
: "Start"

, "Connected"
: "Bağlandı"

, "Disconnected"
: "Bağlantı kesildi"

, "Duration"
: "Süre"

, "Ringing"
: "Çalıyor"

, "Direction"
: "Yön"

, "Source"
: "Kaynak"

, "Destination"
: "Muhatap"

, "Phone"
: ""

, "Phones"
: "Telefonlar"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Sazı"

, "Cancel"
: "İptal"

, "Dial"
: "Ara"

, "Error"
: "Hata"

, "Not possible to dial."
: "Arama mümkün değildir"

, "Edit phone settings"
: "Telefon azarlarını düzelt"

, "Dial number"
: "Numarayı ara"

, "Initiate a new outgoing call"
: "Yeni giden arama"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Kişiyi ara"

, "Work"
: "İş"

, "Home"
: "Ev"

, "Cell"
: "Cep"

, "Cell private"
: "Özel cep"

, "Incoming call"
: "Gelen arama"

, "Outgoing call"
: "Giden arama"

, "unknown number"
: "Bilinmeyen numara"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-tr_TR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Turkish (Turkey) (http://www.transifex.com/tine20/tine20/language/tr_TR/)\nLanguage: tr_TR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Gelen arama"

, "Outgoing call"
: "Giden arama"

, "unknown number"
: "Bilinmeyen numara"

, "Phone"
: ""

, "Line"
: "Hat"

, "Number"
: "Sazı"

, "Cancel"
: "İptal"

, "Dial"
: "Ara"

, "Error"
: "Hata"

, "Not possible to dial."
: "Arama mümkün değildir"

, "Call contact"
: "Kişiyi ara"

, "Work"
: "İş"

, "Home"
: "Ev"

, "Cell"
: "Cep"

, "Cell private"
: "Özel cep"

, "Edit phone settings"
: "Telefon azarlarını düzelt"

, "Dial number"
: "Numarayı ara"

, "Initiate a new outgoing call"
: "Yeni giden arama"

, "Phones"
: "Telefonlar"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Numaram"

, "Start"
: "Start"

, "Connected"
: "Bağlandı"

, "Disconnected"
: "Bağlantı kesildi"

, "Duration"
: "Süre"

, "Ringing"
: "Çalıyor"

, "Direction"
: "Yön"

, "Source"
: "Kaynak"

, "Destination"
: "Muhatap"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
